@@ -1,4 +1,4 @@
-#### $Id: misc-goodies.R,v 1.42 2012/11/01 19:54:15 maechler Exp $
+#### $Id: misc-goodies.R,v 1.43 2013/08/03 08:05:21 maechler Exp $
 #### misc-goodies.R
 #### ~~~~~~~~~~~~~~  SfS - R - goodies that are NOT in
 ####		"/u/sfs/R/SfS/R/u.goodies.R"
@@ -217,11 +217,6 @@ histBxp <-
 	  medlwd = medlwd, whisklty = whisklty, staplelty = staplelty)
 }
 
-hist.bxp <- function(x, ...) {
-    warning("hist.bxp(..) is deprecated -- use  histBxp(..)  instead!")
-    histBxp(x, ...)
-}
-
 
 ##-#### Print & Strings  ########
 ##-###  ===============  ########
