@@ -1,11 +1,5 @@
 ####--- Utilities -----------------
 
-u.assign0 <- function(x, value, immediate = FALSE) {
-    ## Purpose: Simple function with identical UI for both R & S
-    ## Author: Martin Maechler, Date: 7 Jul 1999
-    assign(x, value, envir = .GlobalEnv)
-}
-u.get0 <- function(x) get(x, envir = .GlobalEnv)
 u.sys <- function(..., intern=TRUE)
     system(paste(..., sep=""), intern=intern)
 
